@@ -18,6 +18,8 @@ extern "C"
 
 /// Represents a pointer to any type.
 typedef void *NSTDAny;
+/// Represents a const pointer to any type.
+typedef const void *NSTDAnyConst;
 
 /// Represents a size of any type, such as a memory block.
 typedef size_t NSTDUSize;
@@ -25,27 +27,38 @@ typedef size_t NSTDUSize;
 typedef ptrdiff_t NSTDISize;
 
 /// 8-bit unsigned int.
-typedef uint_fast8_t NSTDUInt8;
+typedef uint_least8_t NSTDUInt8;
 /// 8-bit signed int.
-typedef int_fast8_t NSTDInt8;
+typedef int_least8_t NSTDInt8;
 /// 16-bit unsigned int.
-typedef uint_fast16_t NSTDUInt16;
+typedef uint_least16_t NSTDUInt16;
 /// 16-bit signed int.
-typedef int_fast16_t NSTDInt16;
+typedef int_least16_t NSTDInt16;
 /// 32-bit unsigned int.
-typedef uint_fast32_t NSTDUInt32;
+typedef uint_least32_t NSTDUInt32;
 /// 32-bit signed int.
-typedef int_fast32_t NSTDInt32;
+typedef int_least32_t NSTDInt32;
 /// 64-bit unsigned int.
-typedef uint_fast64_t NSTDUInt64;
+typedef uint_least64_t NSTDUInt64;
 /// 64-bit signed int.
-typedef int_fast64_t NSTDInt64;
+typedef int_least64_t NSTDInt64;
 
 /// 32-bit float.
 typedef float NSTDFloat32;
 /// 64-bit float.
 typedef double NSTDFloat64;
 
+/// Alias for C's char primitive.
+typedef char NSTDChar;
+/// Represents a 8-bit char.
+typedef NSTDUInt8 NSTDChar8;
+/// Represents a 16-bit char.
+typedef NSTDUInt16 NSTDChar16;
+/// Represents a 32-bit char.
+typedef NSTDUInt32 NSTDChar32;
+/// Represents a unicode char type.
+typedef NSTDChar32 NSTDUnichar;
+
 /// Represents a byte.
 typedef NSTDUInt8 NSTDByte;
 
@@ -58,23 +71,6 @@ typedef enum
     NSTD_BOOL_TRUE
 } NSTDBool;
 
-/// Represents a signed range.
-typedef struct
-{
-    /// Start of the range (included).
-    NSTDInt64 start;
-    /// End of the range (exluded).
-    NSTDInt64 end;
-} NSTDIRange;
-/// Represents an unsigned range.
-typedef struct
-{
-    /// Start of the range (included).
-    NSTDUInt64 start;
-    /// End of the range (exluded).
-    NSTDUInt64 end;
-} NSTDURange;
-
 #ifdef __cplusplus
 }
 #endif
